==> fedmsg-0.1.2.tar.gz: fedmsg-0.1.2/fedmsg/commands/tail.py <==
import pprint
import time

import pygments
import pygments.lexers
import pygments.formatters

import fedmsg
import fedmsg.json
from fedmsg.commands import command


extra_args = [
    (['--topic'], {
        'dest': 'topic',
        'help': 'The topic pattern to listen for.  Everything by default.',
        'default': '',
    }),
    (['--pretty'], {
        'dest': 'pretty',
        'help': 'Pretty print the JSON messages.',
        'default': False,
        'action': 'store_true',
    }),
    (['--really-pretty'], {
        'dest': 'really_pretty',
        'help': 'Extra-pretty print the JSON messages.',
        'default': False,
        'action': 'store_true',
    }),
]


@command(extra_args=extra_args)
def tail(**kw):
    """ Watch the bus. """

    # Disable sending
    kw['publish_endpoint'] = None
    # Disable timeouts.  We want to tail forever!
    kw['timeout'] = 0
    fedmsg.init(**kw)

    # Build a message formatter
    formatter = lambda d: d
    if kw['pretty']:
        def formatter(d):
            d['timestamp'] = time.ctime(d['timestamp'])
            return "\n" + pprint.pformat(d)

    if kw['really_pretty']:
        def formatter(d):
            fancy = pygments.highlight(
                fedmsg.json.pretty_dumps(d),
                pygments.lexers.JavascriptLexer(),
                pygments.formatters.TerminalFormatter()
            ).strip()
            return "\n" + fancy

    # The "proper" fedmsg way to do this would be to spin up or connect to an
    # existing Moksha Hub and register a consumer on the "*" topic that simply
    # prints out each message it consumes.  That seems like overkill, so we're
    # just going to directly access the endpoints ourself.

    # TODO -- colors?
    # TODO -- tabular layout?
    for name, ep, topic, message in fedmsg.__context._tail_messages(**kw):
        if '_heartbeat' in topic:
            continue
        print name, ep, topic, formatter(message)

==> fedmsg-0.2.0.tar.gz: fedmsg-0.2.0/fedmsg/commands/tail.py <==
import pprint
import time

import pygments
import pygments.lexers
import pygments.formatters

import fedmsg
import fedmsg.json
from fedmsg.commands import command


extra_args = [
    (['--topic'], {
        'dest': 'topic',
        'help': 'The topic pattern to listen for.  Everything by default.',
        'default': '',
    }),
    (['--pretty'], {
        'dest': 'pretty',
        'help': 'Pretty print the JSON messages.',
        'default': False,
        'action': 'store_true',
    }),
    (['--really-pretty'], {
        'dest': 'really_pretty',
        'help': 'Extra-pretty print the JSON messages.',
        'default': False,
        'action': 'store_true',
    }),
]


@command(name="fedmsg-tail", extra_args=extra_args)
def tail(**kw):
    """ Watch the bus. """

    # Disable sending
    kw['publish_endpoint'] = None
    # Disable timeouts.  We want to tail forever!
    kw['timeout'] = 0
    fedmsg.init(**kw)

    # Build a message formatter
    formatter = lambda d: d
    if kw['pretty']:
        def formatter(d):
            d['timestamp'] = time.ctime(d['timestamp'])
            return "\n" + pprint.pformat(d)

    if kw['really_pretty']:
        def formatter(d):
            fancy = pygments.highlight(
                fedmsg.json.pretty_dumps(d),
                pygments.lexers.JavascriptLexer(),
                pygments.formatters.TerminalFormatter()
            ).strip()
            return "\n" + fancy

    # The "proper" fedmsg way to do this would be to spin up or connect to an
    # existing Moksha Hub and register a consumer on the "*" topic that simply
    # prints out each message it consumes.  That seems like overkill, so we're
    # just going to directly access the endpoints ourself.

    # TODO -- colors?
    # TODO -- tabular layout?
    for name, ep, topic, message in fedmsg.__context._tail_messages(**kw):
        if '_heartbeat' in topic:
            continue
        print name, ep, topic, formatter(message)
